==> apache-log4j-2.24.1-src.zip: log4j-api-test/src/test/java/org/apache/logging/log4j/util/PropertySourceCamelCaseTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.util;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.MethodSource;

public class PropertySourceCamelCaseTest {

    public static Object[][] data() {
        return new Object[][] {
            {"", Collections.singletonList("")},
            {"foo", Collections.singletonList("foo")},
            {"fooBar", Arrays.asList("foo", "bar")},
            {"oneTwoThree", Arrays.asList("one", "two", "three")},
        };
    }

    @ParameterizedTest
    @MethodSource("data")
    public void testJoinAsCamelCase(final CharSequence expected, final List<String> tokens) {
        assertEquals(expected, PropertySource.Util.joinAsCamelCase(tokens));
    }
}

==> apache-log4j-2.25.2-src.zip: log4j-api-test/src/test/java/org/apache/logging/log4j/util/PropertySourceCamelCaseTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.util;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.MethodSource;

class PropertySourceCamelCaseTest {

    public static Object[][] data() {
        return new Object[][] {
            {"", Collections.singletonList("")},
            {"foo", Collections.singletonList("foo")},
            {"fooBar", Arrays.asList("foo", "bar")},
            {"oneTwoThree", Arrays.asList("one", "two", "three")},
        };
    }

    @ParameterizedTest
    @MethodSource("data")
    void testJoinAsCamelCase(final CharSequence expected, final List<String> tokens) {
        assertEquals(expected, PropertySource.Util.joinAsCamelCase(tokens));
    }
}
